| Package name                                                  | Package hash                                                  |
| ------------------------------------------------------------- | ------------------------------------------------------------- |
| protocol/valory/abci/0.1.0                                    | `bafybeig3dj5jhsowlvg3t73kgobf6xn4nka7rkttakdb2gwsg5bp7rt7q4` |
| connection/valory/abci/0.1.0                                  | `bafybeiedhipcrpx7sg7qwitwox6iqrbbb4vfnvqqyok2vc6wq6inrcszey` |
| connection/valory/ipfs/0.1.0                                  | `bafybeia7kzgw4tmkl6k2vjbnss4egvhcf4fmt7cnmpjjjbjogz2bu2j3fu` |
| contract/valory/gnosis_safe_proxy_factory/0.1.0               | `bafybeidzdv6zjst5likperhuqdzsb4yix6ey5ir45nwdcquw3asuqmqdlu` |
| contract/valory/component_registry/0.1.0                      | `bafybeialw5eaa4v54s7i3sjsuy6d5k624quhxhziqntwq5hnz4g646sb7m` |
| contract/valory/agent_registry/0.1.0                          | `bafybeibkj4pm6ziqh2fl3xfsjiou4ibnxlipmvmqhgvc7xwpnaddbtxzli` |
| contract/valory/registries_manager/0.1.0                      | `bafybeighjuqdj2oq6tqckf7j3mqtighe7lpaahh7qt3sqxtbtjlur4tmj4` |
| contract/valory/service_manager/0.1.0                         | `bafybeiea3bophgb6ikqvpd7lzyluthlhoazbbrknvfncu4j7wbubfsrjeu` |
| skill/valory/test_ipfs_abci/0.1.0                             | `bafybeicxpeo5ypjvu367pksuufsrza4cngxl4nncdido53r3ryovwmvxfy` |
| agent/valory/test_ipfs/0.1.0                                  | `bafybeibixyacbe3hr7nhv4lnumvhhljy7p6ys7itfkqhhtiyjkvavjj5ou` |
| contract/valory/service_registry/0.1.0                        | `bafybeid4wyte27tanmeiyzkjfvtvf5yyjngdsvsqvve5bzxwtzjoioubgi` |
| protocol/valory/tendermint/0.1.0                              | `bafybeicusvezoqlmyt6iqomcbwaz3xkhk2qf3d56q5zprmj3xdxfy64k54` |
| protocol/valory/ipfs/0.1.0                                    | `bafybeihlgai5pbmkb6mjhvgy4gkql5uvpwvxbpdowczgz4ovxat6vajrq4` |
| skill/valory/abstract_abci/0.1.0                              | `bafybeihkrunmigvlcze7uxhafj2h3kvpf2kifggq7zqj42n2we4mcwuvou` |
| contract/valory/gnosis_safe/0.1.0                             | `bafybeibzfhpib5fw3wady6dhq5bfgo37o437bi4s3hthbvvit7byvbalg4` |
| skill/valory/abstract_round_abci/0.1.0                        | `bafybeib2jw7hjccou42wis35orckwycb2dgjk7yw46anuqysf2h7su3fi4` |
| contract/valory/multisend/0.1.0                               | `bafybeigjywkl7hydjsrkogob3xebj2ifhqwmfhhxoeyrndzhhxi5u6amey` |
| skill/valory/transaction_settlement_abci/0.1.0                | `bafybeiftbgfzp36bknbwus3fx2equmhgmboy4qd5myex76xfc4ze6o7b54` |
| skill/valory/registration_abci/0.1.0                          | `bafybeidgoqi7fa2gb56hdfsf74bbunfii63zgeo4qhggb66ofver2n2gya` |
| skill/valory/reset_pause_abci/0.1.0                           | `bafybeievxhu6u5r5wlpjfzcwuowlbanhfbi25saf25qit53jauv4kq6gne` |
| skill/valory/termination_abci/0.1.0                           | `bafybeihpp4li6jw3co4c4jferrtzobq2ydoc3dcn67esqrg5ebvyoac66e` |
| skill/valory/counter/0.1.0                                    | `bafybeibzjqpzumbj2ts6lh6mgfj2t2mabgq25qrdhubbwjonnxwnhcj3cu` |
| skill/valory/counter_client/0.1.0                             | `bafybeiaqdfulxamdshw7fykfkqvkpvjb5bnmhv7ffrjiwdi4ktiulklx6q` |
| skill/valory/hello_world_abci/0.1.0                           | `bafybeidhftdlf24itdpzs456btixret4deeis35jdqesh3xo54ukxegdrq` |
| skill/valory/register_reset_abci/0.1.0                        | `bafybeigda2s3nouoehbttbcyewhdolngq4m5ibnwr2driell2ufustgxga` |
| skill/valory/register_termination_abci/0.1.0                  | `bafybeih67ylxwvmc7wamw2sjkfd77zglovqn2gziwewlgeo6pndhonbkyu` |
| skill/valory/test_abci/0.1.0                                  | `bafybeibsosoucoq6oiohxrpzllen63r6ul5q7ne2kwfvnp44sw43cpeady` |
| agent/valory/abstract_abci/0.1.0                              | `bafybeib4o2zojkbk4kympvyahbhezzbmcottzk7cmnr6yosoiruwr4ze5i` |
| agent/valory/counter/0.1.0                                    | `bafybeidkwjanxwjnx74gpmm4x4nvevif5bhofyunyhsi6r2qtzxsqnsafq` |
| agent/valory/counter_client/0.1.0                             | `bafybeicv6jsvvhvtzizko7eewukcfkg3is5dzn47l5ylgvdo4dzjof5inu` |
| agent/valory/hello_world/0.1.0                                | `bafybeic3czcb7fpzru3fl4noxdwgwyzirqk6cqh763h6aio7ugl6qm5gha` |
| agent/valory/register_reset/0.1.0                             | `bafybeibjuczg4bpkpt5m26mdeolg5ooh6wfsfhm3e5xsmmw3th6nsawsne` |
| agent/valory/register_termination/0.1.0                       | `bafybeig4yehd4oseko3pbp6x23h7qmmcvckro66uw5hpecezcslygtjtym` |
| agent/valory/registration_start_up/0.1.0                      | `bafybeied4jwpijvcudlvu3h63gwvkdr4cnazcjk3b335ibgdjpkq4llrn4` |
| agent/valory/test_abci/0.1.0                                  | `bafybeid2daa6abk4z42so7bbpbgy6mgfrxwa5upjmayf5jw3ej2du2ozqa` |
| service/valory/counter/0.1.0                                  | `bafybeihnd72avnqtn5ig6ikuxge2kgcoo2clt5bxqo3ar4mesdg7s7744q` |
| service/valory/hello_world/0.1.0                              | `bafybeiangkjd6y5jjpubeog25lggrmq3y64b2cqurhmxs26i4tddksbhiq` |
| service/valory/register_reset/0.1.0                           | `bafybeig2hgffe3nijhr6wlia2sluzt4p2al63faqxrriwpss4y5gutqbj4` |
| skill/valory/register_reset_recovery_abci/0.1.0               | `bafybeienpr3zxuddgfwuqpgdc32qez6tdldluka6t4dwyltyx2twy6toze` |
| agent/valory/register_reset_recovery/0.1.0                    | `bafybeicyxwchnbuqmbr3tvbesd7me4xpeuesgj7oo4wjwppkpcq6qgc7fq` |
| contract/valory/multicall2/0.1.0                              | `bafybeiaegx2j5w6le2fhvzmx7stzujuezqfvicvnyqebtipivkek2cgh7m` |
| protocol/open_aea/signing/1.0.0                               | `bafybeibqlfmikg5hk4phzak6gqzhpkt6akckx7xppbp53mvwt6r73h7tk4` |
| protocol/valory/acn/1.1.0                                     | `bafybeignmc5uh3vgpuckljcj2tgg7hdqyytkm6m5b6v6mxtazdcvubibva` |
| protocol/valory/http/1.0.0                                    | `bafybeifyoio7nlh5zzyn5yz7krkou56l22to3cwg7gw5v5o3vxwklibhty` |
| protocol/valory/ledger_api/1.0.0                              | `bafybeih6hfzj2obw5oajnt6ng6355edgvi5ngoaub44vpuszqoplfvyaom` |
| protocol/valory/contract_api/1.0.0                            | `bafybeidv6wxpjyb2sdyibnmmum45et4zcla6tl63bnol6ztyoqvpl4spmy` |
| connection/valory/http_client/0.23.0                          | `bafybeidykl4elwbcjkqn32wt5h4h7tlpeqovrcq3c5bcplt6nhpznhgczi` |
| connection/valory/ledger/0.19.0                               | `bafybeicxcypcg2lxmtktbmuhqcyluzmasfsdeljyk2pvaabzc3h2jmcsui` |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeidwcobzb7ut3efegoedad7jfckvt2n6prcmd4g7xnkm6hp6aafrva` |
